import fetchPonyfill from 'fetch-ponyfill';
import FormData from 'form-data';
import { Environment } from '.';
export class BugSplatApiClient {
    constructor(_host = 'https://app.bugsplat.com', _environment = Environment.Node) {
        this._host = _host;
        this._environment = _environment;
        this._createFormData = () => new FormData();
        this._fetch = fetchPonyfill().fetch;
        this._headers = {};
    }
    createFormData() {
        return this._createFormData();
    }
    async fetch(route, init = {}) {
        if (!init.headers) {
            init.headers = {};
        }
        if (this._environment === Environment.Browser) {
            init.credentials = 'include';
        }
        if (this._environment === Environment.Node) {
            init.headers ? init.headers = { ...init.headers, ...this._headers } : null;
        }
        const url = new URL(route, this._host);
        return this._fetch(url.href, init);
    }
    async login(email, password) {
        const url = new URL('/api/authenticatev3', this._host);
        const formData = this._createFormData();
        formData.append('email', email);
        formData.append('password', password);
        formData.append('Login', 'Login');
        const response = await this._fetch(url.href, {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            redirect: 'follow'
        });
        if (response.status === 401) {
            throw new Error('Invalid email or password');
        }
        if (this._environment === Environment.Node) {
            const cookie = this.parseCookies(response);
            const xsrfToken = this.parseXsrfToken(cookie);
            this._headers['cookie'] = cookie;
            this._headers['xsrf-token'] = xsrfToken;
        }
        return response;
    }
    parseCookies(response) {
        return response.headers.get('set-cookie') ?? '';
    }
    parseXsrfToken(cookie) {
        const regex = new RegExp(/xsrf-token=[^;]*/g);
        const matches = cookie.match(regex);
        if (!matches) {
            throw new Error('Could not parse XSRF token');
        }
        const xsrfCookie = matches[0];
        const xsrfToken = xsrfCookie.split('=')[1];
        return xsrfToken;
    }
}
//# sourceMappingURL=bugsplat-api-client.js.map